summaryrefslogtreecommitdiffstats
path: root/tdecore/network/kresolver.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /tdecore/network/kresolver.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/network/kresolver.h')
-rw-r--r--tdecore/network/kresolver.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/network/kresolver.h b/tdecore/network/kresolver.h
index 5e20e174a..3de19acd3 100644
--- a/tdecore/network/kresolver.h
+++ b/tdecore/network/kresolver.h
@@ -73,10 +73,10 @@ public:
KResolverEntry();
/**
* Constructs a new KResolverEntry from a KSocketAddress
* and other data.
*
* The KSocketAddress @p addr parameter will be deep-copied.
*
* @param addr the address that was resolved
* @param socktype the socket type of the resolved address
@@ -84,7 +84,7 @@ public:
* @param canonName the canonical name of the resolved hostname
* @param encodedName the ASCII-compatible encoding of the hostname
*/
- KResolverEntry(const KSocketAddress& addr, int socktype, int protocol,
+ KResolverEntry(const TDESocketAddress& addr, int socktype, int protocol,
const TQString& canonName = TQString::null,
const TQCString& encodedName = TQCString());
@@ -92,7 +92,7 @@ public:
* Constructs a new KResolverEntry from raw forms of
* socket addresses and other data.
*
* This constructor instead creates an internal KSocketAddress object.
*
* @param sa the sockaddr structure containing the raw address
* @param salen the length of the sockaddr structure
@@ -123,7 +123,7 @@ public:
/**
* Retrieves the socket address associated with this entry.
*/
- KSocketAddress address() const;
+ TDESocketAddress address() const;
/**
* Retrieves the length of the socket address structure.
@@ -73,10 +73,10 @@ public:
KResolverEntry();
/**
- * Constructs a new KResolverEntry from a KSocketAddress
+ * Constructs a new KResolverEntry from a TDESocketAddress
* and other data.
*
@@ -73,10 +73,10 @@ public:
* and other data.
*
- * The KSocketAddress @p addr parameter will be deep-copied.
+ * The TDESocketAddress @p addr parameter will be deep-copied.
*
* @param addr the address that was resolved
@@ -92,7 +92,7 @@ public:
* socket addresses and other data.
*
- * This constructor instead creates an internal KSocketAddress object.
+ * This constructor instead creates an internal TDESocketAddress object.
*
* @param sa the sockaddr structure containing the raw address